@@ -1,4 +1,4 @@
-version = "0.0.20"
+version = "0.0.25"
 author = "RedHog (Egil Moeller)"
 author_email = "egil.moller@freecode.no"
 license = "GPL"
@@ -7,4 +7,4 @@ name = "appomatic_cmsplugin_phlog"
 description = "Integrates django-cms and Photologue"
 keywords = "appomatic django-cms photologue"
 url = "https://github.com/benliles/cmsplugin-phlog"
-install_requires = ['appomatic-django-cms', 'appomatic_photolog', 'cmsplugin-phlog']
+install_requires = ['appomatic_django_cms=='+version, 'appomatic_photolog=='+version, 'cmsplugin-phlog']
